(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      5292,        169]
NotebookOptionsPosition[      4713,        147]
NotebookOutlinePosition[      5090,        163]
CellTagsIndexPosition[      5047,        160]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quiet", "@", 
  RowBox[{"<<", "PhysicalConstants`"}]}]], "Input",
 CellChangeTimes->{{3.7005491305199304`*^9, 3.7005491419859505`*^9}, {
  3.7005491749332085`*^9, 3.700549189534834*^9}}],

Cell[BoxData[
 RowBox[{"VacuumPermittivity", "//", "N"}]], "Input",
 CellChangeTimes->{{3.700549194121242*^9, 3.7005492068820643`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curl", "[", "vect_", "]"}], ":=", 
  RowBox[{"Curl", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"div", "[", "vect_", "]"}], ":=", 
  RowBox[{"Div", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.700550060742917*^9, 3.7005500616789184`*^9}, {
  3.7005501938755503`*^9, 3.700550278115699*^9}, {3.7005506417055373`*^9, 
  3.700550645012743*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"Efi", "[", "r", "]"}], ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hvect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"Hz", "[", "r", "]"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.700550650020352*^9, 3.7005506818912077`*^9}}],

Cell[BoxData[
 RowBox[{"eqn1", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Hvect", "]"}], "\[Equal]", 
     RowBox[{"\[Gamma]", "*", "Evect"}]}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550692748827*^9, 3.7005507108136587`*^9}, {
  3.70055075148293*^9, 3.7005507581441417`*^9}, {3.700550802198619*^9, 
  3.700550809156231*^9}}],

Cell[BoxData[
 RowBox[{"eqn2", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Evect", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", "I"}], "*", "\[Omega]", "*", "\[Mu]", "*", "Hvect"}]}], 
    "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550827314663*^9, 3.7005508948783817`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqn1", ",", "eqn2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Efi", "[", "r", "]"}], ",", 
        RowBox[{"Hz", "[", "r", "]"}]}], "}"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"sol", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Omega]", ">", "0"}], ",", 
      RowBox[{"r", ">", "0"}], ",", 
      RowBox[{"\[Mu]", ">", "0"}], ",", 
      RowBox[{"\[Gamma]", ">", "0"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.7005509793369303`*^9, 3.700551034514227*^9}, {
  3.7005511058531523`*^9, 3.700551158612445*^9}, {3.700551745777836*^9, 
  3.700551750192643*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], 
   RowBox[{"3", "/", "4"}]], "//", "ComplexExpand"}]], "Input",
 CellChangeTimes->{{3.700551776385089*^9, 3.7005517804410963`*^9}}],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SqrtBox[
     FractionBox["2", 
      RowBox[{"\[Omega]", "*", "\[Gamma]", "*", "\[Mu]"}]]], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", "\[Rule]", 
       RowBox[{
        RowBox[{"N", "[", "VacuumPermeability", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"2.", "Pi", "*", "f"}]}], ",", 
      RowBox[{"\[Gamma]", "\[Rule]", 
       RowBox[{"57", "*", 
        SuperscriptBox["10", "6"]}]}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ">", "0"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"f", "\[Rule]", "50"}]}]}], "Input",
 CellChangeTimes->{{3.7005521322841144`*^9, 3.700552266787551*^9}}]
},
WindowSize->{1137, 761},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->2.299999952316284,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 210, 4, 68, "Input"],
Cell[770, 26, 135, 2, 68, "Input"],
Cell[908, 30, 679, 17, 112, "Input"],
Cell[1590, 49, 399, 12, 141, "Input"],
Cell[1992, 63, 412, 10, 97, "Input"],
Cell[2407, 75, 364, 10, 97, "Input"],
Cell[2774, 87, 918, 26, 184, "Input"],
Cell[3695, 115, 222, 6, 99, "Input"],
Cell[3920, 123, 789, 22, 337, "Input"]
}
]
*)

(* End of internal cache information *)
