(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     65350,       1958]
NotebookOptionsPosition[     59593,       1754]
NotebookOutlinePosition[     59970,       1770]
CellTagsIndexPosition[     59927,       1767]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quiet", "@", 
  RowBox[{"<<", "PhysicalConstants`"}]}]], "Input",
 CellChangeTimes->{{3.7005491305199304`*^9, 3.7005491419859505`*^9}, {
  3.7005491749332085`*^9, 3.700549189534834*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VacuumPermittivity", "//", "N"}]], "Input",
 CellChangeTimes->{{3.700549194121242*^9, 3.7005492068820643`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"8.85418781762039`*^-12", " ", "Ampere", " ", "Second"}], 
  RowBox[{"Meter", " ", "Volt"}]]], "Output",
 CellChangeTimes->{3.703571864520975*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pow", "=", 
   RowBox[{"100", "*", 
    SuperscriptBox["10", "3"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eta", "=", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PowerOfLoses", "=", 
  RowBox[{
   FractionBox["Pow", "eta"], "-", "Pow"}]}]}], "Input",
 CellChangeTimes->{{3.7017515267850447`*^9, 3.701751598716771*^9}}],

Cell[BoxData["42857.14285714287`"], "Output",
 CellChangeTimes->{3.7035718645365753`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curl", "[", "vect_", "]"}], ":=", 
  RowBox[{"Curl", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"div", "[", "vect_", "]"}], ":=", 
  RowBox[{"Div", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.700550060742917*^9, 3.7005500616789184`*^9}, {
  3.7005501938755503`*^9, 3.700550278115699*^9}, {3.7005506417055373`*^9, 
  3.700550645012743*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"Ez", "[", "r", "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hvect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"Hfi", "[", "r", "]"}], ",", "0"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.700550650020352*^9, 3.7005506818912077`*^9}, {
  3.7017518642136374`*^9, 3.701751869065246*^9}, {3.7017519056473103`*^9, 
  3.7017519075817137`*^9}, {3.701751957595402*^9, 3.7017519658322163`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqn1", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Hvect", "]"}], "\[Equal]", 
     RowBox[{"\[Gamma]", "*", "Evect"}]}], "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550692748827*^9, 3.7005507108136587`*^9}, {
   3.70055075148293*^9, 3.7005507581441417`*^9}, {3.700550802198619*^9, 
   3.700550809156231*^9}, 3.701751971292226*^9, {3.7017520121954975`*^9, 
   3.701752038294343*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"Hfi", "[", "r", "]"}], "r"], "+", 
   RowBox[{
    SuperscriptBox["Hfi", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "\[Equal]", 
  RowBox[{"\[Gamma]", " ", 
   RowBox[{"Ez", "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.7035718646457753`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqn2", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Evect", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", "I"}], "*", "\[Omega]", "*", "\[Mu]", "*", "Hvect"}]}], 
    "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550827314663*^9, 3.7005508948783817`*^9}, {
  3.701752068683197*^9, 3.701752094844443*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["Ez", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Mu]", " ", "\[Omega]", " ", 
   RowBox[{"Hfi", "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.703571864661375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqn1", ",", "eqn2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ez", "[", "r", "]"}], ",", 
        RowBox[{"Hfi", "[", "r", "]"}]}], "}"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"solSimpl", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"sol", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", ">", "0"}], ",", 
       RowBox[{"r", ">", "0"}], ",", 
       RowBox[{"\[Mu]", ">", "0"}], ",", 
       RowBox[{"\[Gamma]", ">", "0"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}]}]}], "Input",
 CellChangeTimes->{{3.7005509793369303`*^9, 3.700551034514227*^9}, {
  3.7005511058531523`*^9, 3.700551158612445*^9}, {3.700551745777836*^9, 
  3.700551750192643*^9}, {3.7017521067784634`*^9, 3.701752149054538*^9}, {
  3.701752650033818*^9, 3.7017526528106227`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Ez", "[", "r", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"3", "/", "4"}]], " ", "r", " ", 
        SqrtBox[
         RowBox[{"\[Gamma]", " ", "\[Mu]", " ", "\[Omega]"}]]}]}], "]"}], " ", 
     RowBox[{"C", "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Hfi", "[", "r", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]], " ", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"1", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"3", "/", "4"}]], " ", "r", " ", 
          SqrtBox[
           RowBox[{"\[Gamma]", " ", "\[Mu]", " ", "\[Omega]"}]]}]}], "]"}], 
       " ", 
       RowBox[{"C", "[", "1", "]"}]}], 
      SqrtBox[
       FractionBox[
        RowBox[{"\[Mu]", " ", "\[Omega]"}], "\[Gamma]"]]]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7035718648329754`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"current", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ez", "[", "r", "]"}], "*", "\[Gamma]", "*", "2", "*", "Pi", 
      "*", "r"}], "/.", "solSimpl"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "rmax"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.701752505983165*^9, 3.7017525128939767`*^9}, {
   3.70175254886764*^9, 3.701752575434487*^9}, 3.7017526681922493`*^9}],

Cell[BoxData[
 RowBox[{"\[Pi]", " ", 
  SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", 
  RowBox[{"C", "[", "1", "]"}], " ", 
  RowBox[{"Hypergeometric0F1Regularized", "[", 
   RowBox[{"2", ",", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", "\[Mu]", " ", 
     "\[Omega]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.703571865113776*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solC1", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"current", "\[Equal]", "Itotal"}], ",", 
     RowBox[{"C", "[", "1", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.701752809503442*^9, 3.7017528416394978`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
   RowBox[{"Itotal", "/", 
    RowBox[{"(", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", 
      RowBox[{"Hypergeometric0F1Regularized", "[", 
       RowBox[{"2", ",", 
        RowBox[{
         FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", "\[Mu]", " ", 
         "\[Omega]"}]}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.703571865129376*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ezfinal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Ez", "[", "r", "]"}], "/.", "solSimpl"}], "/.", 
   "solC1"}]}]], "Input",
 CellChangeTimes->{{3.701752856958725*^9, 3.701752889344382*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"Itotal", " ", 
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"3", "/", "4"}]], " ", "r", " ", 
      SqrtBox[
       RowBox[{"\[Gamma]", " ", "\[Mu]", " ", "\[Omega]"}]]}]}], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", 
   RowBox[{"Hypergeometric0F1Regularized", "[", 
    RowBox[{"2", ",", 
     RowBox[{
      FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["rmax", "2"], " ", "\[Gamma]", " ", "\[Mu]", " ", 
      "\[Omega]"}]}], "]"}]}]]], "Output",
 CellChangeTimes->{3.703571865129376*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]0", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"VacuumPermeability", "//", "N"}], ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.701753147400035*^9, 3.701753163717664*^9}}],

Cell[BoxData["1.2566370614359173`*^-6"], "Output",
 CellChangeTimes->{3.7035718651449757`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"2.", "Pi", "*", "50"}]}], ",", 
     RowBox[{"\[Mu]", "->", "\[Mu]0"}], ",", 
     RowBox[{"rmax", "\[Rule]", "0.05"}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{"57", "*", 
       SuperscriptBox["10", "6"]}]}], ",", 
     RowBox[{"Itotal", "\[Rule]", "1"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7017531308796062`*^9, 3.701753141784025*^9}, {
  3.7017531733428802`*^9, 3.7017531993013263`*^9}, {3.701753334905965*^9, 
  3.701753340007174*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Abs", "[", 
  RowBox[{"Ezfinal", "/.", "params"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"2.9619948765740187`*^-7", " ", 
  RowBox[{"Abs", "[", 
   RowBox[{"BesselJ", "[", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"106.072376315617`", "\[VeryThinSpace]", "-", 
        RowBox[{"106.07237631561702`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "r"}]}], "]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.703571865176176*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Ezfinal", "/.", "params"}], "]"}], ",", 
   RowBox[{"Evaluate", "[", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "0.05"}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.70175320714814*^9, 3.701753222117767*^9}, {
  3.701753270992653*^9, 3.701753323065544*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0nk41PsXB3DZ2pAsWUJCKVq5Kco5lroRtySSUiRZE4Mo+9hFofkOY2tc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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 0.05}, {0., 8.776633644168689*^-6}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.7035718652697763`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"2.", "Pi", "*", "50"}]}], ",", 
     RowBox[{"\[Mu]", "->", "\[Mu]0"}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{"57", "*", 
       SuperscriptBox["10", "6"]}]}], ",", 
     RowBox[{"Itotal", "\[Rule]", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"QV", "=", 
  RowBox[{
   RowBox[{"\[Gamma]", "*", 
    SuperscriptBox[
     RowBox[{"Abs", "[", "Ezfinal", "]"}], "2"]}], "/.", 
   "params"}]}]}], "Input",
 CellChangeTimes->{{3.701753562120364*^9, 3.701753586628007*^9}, {
  3.7017544749091673`*^9, 3.701754495984804*^9}, {3.7017545318336673`*^9, 
  3.7017545388380795`*^9}, {3.701754586683364*^9, 3.7017545895849686`*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Abs", "[", 
    FractionBox[
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"106.072376315617`", "\[VeryThinSpace]", "-", 
          RowBox[{"106.07237631561702`", " ", "\[ImaginaryI]"}]}], ")"}], " ",
         "r"}]}], "]"}], 
     RowBox[{
      SuperscriptBox["rmax", "2"], " ", 
      RowBox[{"Hypergeometric0F1Regularized", "[", 
       RowBox[{"2", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "+", 
           RowBox[{"5625.674508620934`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox["rmax", "2"]}]}], "]"}]}]], "]"}], "2"], 
  RowBox[{"57000000", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.7035718653009768`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"length", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ploses", "[", "rmaxx_", "]"}], ":=", 
   RowBox[{"2", "*", "Pi", "*", "length", "*", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"QV", "*", "r"}], "/.", 
       RowBox[{"rmax", "\[Rule]", "rmaxx"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0", ",", "rmaxx"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Ploses", "[", "0.05", "]"}]}], "Input",
 CellChangeTimes->{{3.7017550834974365`*^9, 3.701755199156039*^9}}],

Cell[BoxData["6.519945728408521`*^-6"], "Output",
 CellChangeTimes->{3.7035718653477764`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ratio1", "[", "rmax_", "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"Ploses", "[", "rmax", "]"}], 
     FractionBox["length", 
      RowBox[{"\[Gamma]", "*", "Pi", "*", 
       SuperscriptBox["rmax", "2"]}]]], "/.", "params"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"ratio1", "[", "r", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0.001", ",", "0.05", ",", "0.001"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.7017552311048956`*^9, 3.7017552387957087`*^9}, {
  3.7017552698241634`*^9, 3.7017553075450296`*^9}, {3.701755353908311*^9, 
  3.701755419163226*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw9kQ0s1GEcx//uznnt3S7WZkKqSVFtzev3sVylRNQsWiZjKHWY92iXl5S8
JCqkOO+UmNFI0xqZppjeRKSSaMXuvB3uzuXuf3q2Z89++z3P9/v7fp6tfjyP
AAZFUXtXtuKUVoveHfc7AR3GXDuDEoKufeFxZtZh10q9dOX884icIFjYfp4f
+d8PRVZeZk47Q4jLek8Of4+LwHJItEkbe/V+DPqtZE7za4SI/W1mpfk4HpEu
CRd7DFbf8yE+uOzz1VwIuxG3jHuXEpGkHdA3wRUiXqmXDHGKdtibYCGeOesy
zFOv4eBrVi0vf1X/OqjuOl7lJyFsGrui2orSYBJs2G5gIkKc0i8d5VGxsYZ8
EZoNU/64N2fCIf8HQzAlUvnfgq2801uDN43CDqP68KBs2PdKNhqrzajmuY2P
C1Yvd5TNYGhRaYiMTaNhHZ6zqry5kErqbm7fPIcte4ZN2VfvwLRXxrUcnUOr
ct67kGeNcbKb5+Htb6tQxNsXmq2LuWLV/HlIdtw5YBu1gIJ85YKOq0lWoPei
Kk8BAtI1loexhMEe8cnR8vsIP8Zv8NomUfEsRB6lYzGlJYUBy3OtRcMDlPtw
yqhJKVqUeR8iU+/RObseGU5bKwVhM2UpTq5dVuUvhqHTbv2JNDlcDtxw9B0r
Bn+6aP+RfRSheQigx+Vqni2myF93BUEBYmxaGj/oqhGaTwkyGqLn+2LUSHrI
uKRaVALm0nRu5E818kXJqxRNwa0dQ24MYp7KGegRl2J8He+QUSuD0PzKoPFt
g/4pMybpFnCfzsjKkMQ2yE7NZhKaZzkS/F07X0mZ5MIKLX1WBeqYGfqcIBah
+VagUSuwP/49i2j3l4baa1eiqj7ll8RBndC8K9Elb/LKqVEnNYq466vAdxXJ
HTlsQvOvgnOC9YB6IpscVchxqiHrHYwcmmQT+j+qoWUsQLuXBvkH05eDcg==

     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 1.0000026373455764`},
  Method->{},
  PlotRange->{{0, 0.05}, {1.0000026373455764`, 2.918829438309562}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.001, 0.001}, {0.03837653601927971, 
   0.03837653601927971}}]], "Output",
 CellChangeTimes->{3.703571865800177*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{
    SqrtBox[
     FractionBox["2", 
      RowBox[{"\[Omega]", "*", "\[Gamma]", "*", "\[Mu]"}]]], "/.", 
    "params"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ratio2", "[", "rmax_", "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"Ploses", "[", "rmax", "]"}], 
     FractionBox["length", 
      RowBox[{"\[Gamma]", "*", "Pi", "*", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["rmax", "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"rmax", "-", "a"}], ")"}], "2"]}], ")"}]}]]], "/.", 
    "params"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"ratio2", "[", "r", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"a", "+", "0.0001"}], ",", 
       RowBox[{"5", "a"}], ",", 
       RowBox[{"0.1", "a"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "data2", "]"}]}], "Input",
 CellChangeTimes->{{3.7017556751460752`*^9, 3.7017557319925756`*^9}, {
  3.7017557849702682`*^9, 3.7017558144855204`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJwBkQJu/SFib1JlAgAAACgAAAACAAAAp1HtyCqDgz+9bs9iCFfwP14H1uJw
cYU/kY6Xyr1U8D8Uvb78tl+HP2Tl1mOnL/A/ynKnFv1NiT+0BWfV+vjvP4Eo
kDBDPIs/sEMa9FGO7z843nhKiSqNPwBrU3HaLO8/7pNhZM8Yjz9NZaneztvu
P9IkJb+Kg5A/Z9p8n2ie7j+ufxnMrXqRPzJqYaBCde4/iNoN2dBxkj8hJpyo
Pl/uP2Q1AubzaJM/8QKJJiVa7j9AkPbyFmCUP1xH3lMcY+4/Guvq/zlXlT8I
lobBBHfuP/ZF3wxdTpY/cUGHbsGS7j/RoNMZgEWXP2MTZMZts+4/rPvHJqM8
mD+3t3CigtbuP4hWvDPGM5k/BAzSjuv57j9isbBA6SqaP1ugrUsOHO8/Pgyl
TQwimz9VWo47xzvvPxpnmVovGZw/1bBr2F1Y7z/0wY1nUhCdP2gaNEh0ce8/
0ByCdHUHnj/kHLHO9IbvP6x3doGY/p4/C4EOR/+Y7z+G0mqOu/WfP+D2CCjY
p+8/sZavTW92oD+1Awf42bPvPx7EKdQA8qA/jtjkk2m97z+M8aNakm2hP72o
A0vtxO8/+h4e4SPpoT8Mql+UxsrvP2dMmGe1ZKI/U7fF/U3P7z/VeRLuRuCi
P3xXyujQ0u8/Q6eMdNhboz+FzheqkNXvP7DUBvtp16M/VTtYqcLX7z8eAoGB
+1KkP4d8IS6R2e8/iy/7B43OpD+hMeSVHNvvP/lcdY4eSqU/z7UVvnzc7z9n
iu8UsMWlP9mhjXvC3e8/1Ldpm0FBpj9MZ9gD+d7vP0Ll4yHTvKY/t07sNifg
7z+wEl6oZDinP4acTr9Q4e8/HUDYLvazpz/6cnwEd+LvP2b5ScE=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0.009527525193029641, 0.948504042877259},
  Method->{},
  PlotRange->{{0.009527525193029641, 0.04629487344584524}, {0.948504042877259,
    1.0212482318665217`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.000735346965056312, 0.000735346965056312}, {
   0.0014548837797852543`, 0.0014548837797852543`}}]], "Output",
 CellChangeTimes->{3.7035718661745777`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "example", " ", "of", " ", "induction", " ", "heating", " ", "system", " ",
     "design"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClearAll", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Context", "[", "]"}], "<>", "\"\<*\>\""}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T1", "=", "0"}], ";"}], 
   RowBox[{"(*", "start", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T2", "=", "800"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"desired", " ", "temperature"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"time", "=", "600"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D1", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"length", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"specificHeat", "=", "385"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"density", "=", "8960"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"volume", "=", 
     RowBox[{"length", "*", 
      FractionBox[
       SuperscriptBox["D1", "2"], "4"], "*", "Pi"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"minimalNeededPower", "=", 
     RowBox[{"volume", "*", "density", "*", "specificHeat", "*", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"T2", "-", "T1"}], ")"}], "time"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<minimal power is \>\"", ",", 
     FractionBox["minimalNeededPower", "1000"], ",", "\"\< kW\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", 
     RowBox[{"1.3", "minimalNeededPower"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<chosen power is \>\"", ",", 
     FractionBox["P", "1000"], ",", "\"\< kW\>\""}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.701758265343425*^9, 3.7017584876906157`*^9}, {
  3.7017585212150745`*^9, 3.7017585242570796`*^9}, {3.70175855849914*^9, 
  3.701758569200759*^9}, {3.701758735621851*^9, 3.701758842544439*^9}, {
  3.701759041444788*^9, 3.7017591017232943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"minimal power is \"\>", "\[InvisibleSpace]", 
   "650.234281069401`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["minimal power is ", 650.234281069401, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866205778*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"chosen power is \"\>", "\[InvisibleSpace]", 
   "845.3045653902215`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["chosen power is ", 845.3045653902215, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718662213783`*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"D2", "=", 
   RowBox[{"D1", "+", "0.04"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"params20", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"2.", "Pi", "*", "50"}]}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", 
      RowBox[{"4", "Pi", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "7"}]]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{"57", "*", 
       SuperscriptBox["10", "6"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"params800", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"2.", "Pi", "*", "50"}]}], ",", 
      RowBox[{"\[Mu]", "\[Rule]", 
       RowBox[{"4", "Pi", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "7"}]]}]}], ",", 
      RowBox[{"\[Gamma]", "\[Rule]", 
       FractionBox[
        RowBox[{"57", "*", 
         SuperscriptBox["10", "6"]}], 
        RowBox[{"1", "+", 
         RowBox[{"0.004041", "*", 
          RowBox[{"(", 
           RowBox[{"800", "-", "20"}], ")"}]}]}]]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"depthOfPenetration20", "=", 
   RowBox[{
    SqrtBox[
     FractionBox["2", 
      RowBox[{"\[Omega]", "*", "\[Gamma]", "*", "\[Mu]"}]]], "/.", 
    "params20"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"depthOfPenetration800", "=", 
   RowBox[{
    SqrtBox[
     FractionBox["2", 
      RowBox[{"\[Omega]", "*", "\[Gamma]", "*", "\[Mu]"}]]], "/.", 
    "params800"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d1", "=", 
   RowBox[{"D1", "-", "depthOfPenetration800"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"D2", "+", "depthOfPenetration20"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.701759510896413*^9, 3.7017595121288147`*^9}, {
   3.7017597094691615`*^9, 3.7017597194931793`*^9}, {3.7017598905006795`*^9, 
   3.7017599677832155`*^9}, {3.701760043895749*^9, 3.7017600812578144`*^9}, {
   3.7017601894213023`*^9, 3.7017601993328695`*^9}, 3.701760267995797*^9, {
   3.7017603173501263`*^9, 3.7017603353213577`*^9}, {3.701760457453972*^9, 
   3.7017604690759926`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\!\(\*FractionBox[\(d1\), \(length\)]\)= \>\"", ",", 
   FractionBox["d1", "length"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\!\(\*FractionBox[\(d2\), \(length\)]\)= \>\"", ",", 
   FractionBox["d2", "length"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.701761203071732*^9, 3.7017612202677155`*^9}, {
  3.7023633415234814`*^9, 3.702363348075493*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d1\\), \\(length\\)]\\)= \"\>", 
   "\[InvisibleSpace]", "0.14039504504632477`"}],
  SequenceForm[
  "\!\(\*FractionBox[\(d1\), \(length\)]\)= ", 0.14039504504632477`],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866252578*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d2\\), \\(length\\)]\\)= \"\>", 
   "\[InvisibleSpace]", "0.1747137625965148`"}],
  SequenceForm[
  "\!\(\*FractionBox[\(d2\), \(length\)]\)= ", 0.1747137625965148],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866268178*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nagaoka1", "=", "0.9709"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nagaoka2", "=", "0.9639"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L1", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["1", "2"], "*", "\[Mu]", "*", 
     FractionBox[
      RowBox[{
       SuperscriptBox["d1", "2"], "*", "Pi"}], 
      RowBox[{"4", "*", "length"}]], "*", "Nagaoka1"}], "/.", "params800"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<L1= \>\"", ",", 
   RowBox[{"L1", "*", 
    SuperscriptBox["10", "9"]}], ",", "\"\< nH\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.7017614937658567`*^9, 3.701761498133865*^9}, {
  3.7017615384911356`*^9, 3.7017615447311463`*^9}, {3.7017616000020437`*^9, 
  3.7017617615871277`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"L1= \"\>", "\[InvisibleSpace]", "37.775289662451925`", 
   "\[InvisibleSpace]", "\<\" nH\"\>"}],
  SequenceForm["L1= ", 37.775289662451925`, " nH"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866283778*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"L2", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["N2", "2"], "*", "\[Mu]", "*", 
     FractionBox[
      RowBox[{
       SuperscriptBox["d2", "2"], "*", "Pi"}], 
      RowBox[{"4", "*", "length"}]], "*", "Nagaoka1"}], "/.", "params20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<L2= \>\"", ",", 
   RowBox[{"L2", "*", 
    SuperscriptBox["10", "9"]}], ",", "\"\< nH\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.701761789869977*^9, 3.701761806328006*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"L2= \"\>", "\[InvisibleSpace]", 
   RowBox[{"58.50035149408794`", " ", 
    SuperscriptBox["N2", "2"]}], "\[InvisibleSpace]", "\<\" nH\"\>"}],
  SequenceForm["L2= ", 58.50035149408794 $CellContext`N2^2, " nH"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866299378*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R1", "=", 
   RowBox[{
    RowBox[{"Pi", "*", 
     FractionBox["d1", 
      RowBox[{"\[Gamma]", "*", "depthOfPenetration800", "*", "length"}]]}], "/.",
     "params800"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<R1= \>\"", ",", 
   RowBox[{
    SuperscriptBox["10", "6"], "R1"}], ",", "\"\< \[Mu]\[CapitalOmega]\>\""}],
   "]"}]}], "Input",
 CellChangeTimes->{{3.7017619660722866`*^9, 3.7017620564120455`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"R1= \"\>", "\[InvisibleSpace]", "1.6724637845460517`", 
   "\[InvisibleSpace]", "\<\" \[Mu]\[CapitalOmega]\"\>"}],
  SequenceForm["R1= ", 1.6724637845460517`, " \[Mu]\[CapitalOmega]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718663149776`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R2", "=", 
   RowBox[{
    RowBox[{"Pi", "*", 
     FractionBox[
      RowBox[{"d2", "*", "1.2", "*", 
       SuperscriptBox["N2", "2"]}], 
      RowBox[{"\[Gamma]", "*", "depthOfPenetration20", "*", "length"}]]}], "/.",
     "params20"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<R2= \>\"", ",", 
   RowBox[{
    SuperscriptBox["10", "6"], "R2"}], ",", "\"\< \[Mu]\[CapitalOmega]\>\""}],
   "]"}]}], "Input",
 CellChangeTimes->{{3.701762122119361*^9, 3.7017621387645903`*^9}, {
  3.701762252317189*^9, 3.701762258448*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"R2= \"\>", "\[InvisibleSpace]", 
   RowBox[{"1.2257042108995184`", " ", 
    SuperscriptBox["N2", "2"]}], 
   "\[InvisibleSpace]", "\<\" \[Mu]\[CapitalOmega]\"\>"}],
  SequenceForm[
  "R2= ", 1.2257042108995184` $CellContext`N2^2, " \[Mu]\[CapitalOmega]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866330578*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"NagaokaMutual", "=", "0.975"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"M", "=", 
  RowBox[{
   RowBox[{"\[Mu]", "*", "N2", "*", 
    FractionBox[
     RowBox[{
      SuperscriptBox["d1", "2"], "*", "Pi"}], 
     RowBox[{"4", "*", "length"}]]}], "/.", "params20"}]}]}], "Input",
 CellChangeTimes->{{3.7023635221249986`*^9, 3.7023635796579*^9}}],

Cell[BoxData[
 RowBox[{"3.890749784988354`*^-8", " ", "N2"}]], "Output",
 CellChangeTimes->{3.703571866346178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"L1", ",", "L2", ",", "M", ",", "R1", ",", "R2"}], "}"}]], "Input",
 CellChangeTimes->{{3.702364193612578*^9, 3.7023642035497956`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.777528966245192`*^-8", ",", 
   RowBox[{"5.8500351494087934`*^-8", " ", 
    SuperscriptBox["N2", "2"]}], ",", 
   RowBox[{"3.890749784988354`*^-8", " ", "N2"}], ",", 
   "1.6724637845460516`*^-6", ",", 
   RowBox[{"1.2257042108995185`*^-6", " ", 
    SuperscriptBox["N2", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7035718663617783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U2", "=", "230"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"R2", "*", "I2"}], "+", 
        RowBox[{"I", "*", "\[Omega]", "*", "L2", "*", "I2"}], "+", 
        RowBox[{"M", "*", "I", "*", "\[Omega]", "*", "I1"}]}], "\[Equal]", 
       "U2"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"R1", "*", "I1"}], "+", 
        RowBox[{"I", "*", "\[Omega]", "*", "L1", "*", "I1"}], "+", 
        RowBox[{"M", "*", "I", "*", "\[Omega]", "*", "I2"}]}], "\[Equal]", 
       "0"}]}], "\[IndentingNewLine]", "}"}], "/.", "params20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solI12", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"eqns", ",", 
      RowBox[{"{", 
       RowBox[{"I1", ",", "I2"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"power", "=", 
   RowBox[{
    RowBox[{"R1", "*", 
     RowBox[{"Abs", "[", 
      SuperscriptBox["I1", "2"], "]"}]}], "/.", "solI12"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"P", "\[Equal]", "power"}], ",", 
   RowBox[{"{", 
    RowBox[{"N2", ",", "10"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["length", "N2"], "/.", "%"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chosenN2", "=", "49"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7023639596433673`*^9, 3.7023641597761183`*^9}, {
  3.702364255731887*^9, 3.7023643095051813`*^9}, {3.70236442814539*^9, 
  3.7023644418578143`*^9}, {3.7023644848982897`*^9, 3.7023644897498984`*^9}, {
  3.702364547235999*^9, 3.702364565815632*^9}, {3.7023646119293127`*^9, 
  3.702364630306145*^9}, {3.7023646954362593`*^9, 3.7023647183526998`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"N2", "\[Rule]", "49.07582933036087`"}], "}"}]], "Output",
 CellChangeTimes->{3.7035718663773785`*^9}],

Cell[BoxData["0.040753259339474796`"], "Output",
 CellChangeTimes->{3.7035718663773785`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqns", "/.", 
   RowBox[{"N2", "->", "chosenN2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", "%", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7023648251348877`*^9, 3.7023648614985514`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"I1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "400149.4763742399`"}], "+", 
     RowBox[{"588957.2730449954`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{"I2", "\[Rule]", 
    RowBox[{"6284.072376882373`", "\[VeryThinSpace]", "-", 
     RowBox[{"12787.144663076959`", " ", "\[ImaginaryI]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.703571866392978*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"inductorLoses", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"R2", "*", 
      RowBox[{"Abs", "[", 
       SuperscriptBox["I2", "2"], "]"}]}], "/.", 
     RowBox[{"N2", "->", "chosenN2"}]}], "/.", "sol"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<loses in the inductor= \>\"", ",", 
   FractionBox["inductorLoses", "1000"], ",", "\"\< kW\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7023649186102514`*^9, 3.7023649925231814`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"loses in the inductor= \"\>", "\[InvisibleSpace]", 
   "597.4137761151956`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["loses in the inductor= ", 597.4137761151956, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718664085784`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"powerInHeatedObject", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"R1", "*", 
      RowBox[{"Abs", "[", 
       SuperscriptBox["I1", "2"], "]"}]}], "/.", 
     RowBox[{"N2", "->", "chosenN2"}]}], "/.", "sol"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<power In Heated Object= \>\"", ",", 
   FractionBox["powerInHeatedObject", "1000"], ",", "\"\< kW\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.702365013037217*^9, 3.7023650852809443`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"power In Heated Object= \"\>", "\[InvisibleSpace]", 
   "847.9228705677504`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["power In Heated Object= ", 847.9228705677504, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703571866424178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<efficiency= \>\"", ",", 
   FractionBox["powerInHeatedObject", 
    RowBox[{"powerInHeatedObject", "+", "inductorLoses"}]], ",", 
   "\"\< -\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.702365091489755*^9, 3.7023651366050344`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"efficiency= \"\>", "\[InvisibleSpace]", "0.5866611578096612`", 
   "\[InvisibleSpace]", "\<\" -\"\>"}],
  SequenceForm["efficiency= ", 0.5866611578096612, " -"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718664397783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"reactivePower", "=", 
   RowBox[{"Im", "[", 
    RowBox[{"U2", "*", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"I2", "/.", "sol"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<reactive power= \>\"", ",", 
   FractionBox["reactivePower", 
    SuperscriptBox["10", "6"]], ",", "\"\< MVAr\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.7023655910494328`*^9, 3.7023656689715695`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"reactive power= \"\>", "\[InvisibleSpace]", 
   "2.9410432725077005`", "\[InvisibleSpace]", "\<\" MVAr\"\>"}],
  SequenceForm["reactive power= ", 2.9410432725077005`, " MVAr"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718664553785`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Xc", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Omega]", "*", "c"}]], "/.", "params20"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"capacityForCompensation", "=", 
   RowBox[{"c", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"reactivePower", "\[Equal]", 
       FractionBox[
        SuperscriptBox["U2", "2"], "Xc"]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<c= \>\"", ",", 
   RowBox[{"1000", "capacityForCompensation"}], ",", "\"\< mF\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.702365683682395*^9, 3.7023656955696163`*^9}, {
  3.702365728501274*^9, 3.702365819636634*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c= \"\>", "\[InvisibleSpace]", "176.968459231291`", 
   "\[InvisibleSpace]", "\<\" mF\"\>"}],
  SequenceForm["c= ", 176.968459231291, " mF"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718664709787`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tg\[Delta]", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "4"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"dielectricLoses", "=", 
  RowBox[{"reactivePower", "*", "tg\[Delta]"}]}]}], "Input",
 CellChangeTimes->{{3.7023660959190693`*^9, 3.702366144071823*^9}}],

Cell[BoxData["294.1043272507701`"], "Output",
 CellChangeTimes->{3.7035718664865785`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"evaluation", " ", "of", " ", "heat", " ", "loses"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cm", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thicknessOfIsolation", "=", 
     RowBox[{"1", "cm"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]", "=", "0.16"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tcoil", "=", "100"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]", "=", 
     RowBox[{"5.67", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "8"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S1", "=", 
     RowBox[{"Pi", "*", "D1", "*", "length"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S2", "=", 
     RowBox[{"Pi", "*", 
      RowBox[{"(", 
       RowBox[{"D2", "-", 
        RowBox[{"2", "thicknessOfIsolation"}]}], ")"}], "*", "length"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]1", "=", "0.78"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]2", "=", "0.95"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PowerOfRadiation", "=", 
     FractionBox[
      RowBox[{"\[Sigma]", "*", "S1", "*", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"T2", "+", "273."}], ")"}], "4"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"Tisol", "+", "273"}], ")"}], "4"]}], ")"}]}], 
      RowBox[{
       FractionBox["1", "\[Epsilon]1"], "+", 
       RowBox[{
        FractionBox["S1", "S2"], "*", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "\[Epsilon]2"], "-", "1"}], ")"}]}]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RthExact", "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[Lambda]", "*", "2", "Pi", "*", "length"}]], "*", 
      RowBox[{"Log", "[", 
       FractionBox["D2", 
        RowBox[{"(", 
         RowBox[{"D2", "-", 
          RowBox[{"2", "thicknessOfIsolation"}]}], ")"}]], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RthApprox", "=", 
     FractionBox["thicknessOfIsolation", 
      RowBox[{"\[Lambda]", "*", "length", "*", "Pi", "*", 
       RowBox[{"(", 
        RowBox[{"D2", "-", "thicknessOfIsolation"}], ")"}]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PowerOfConduction", "=", 
     FractionBox[
      RowBox[{"Tisol", "-", "Tcoil"}], "RthExact"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqnOfHeatTransfer", "=", 
     RowBox[{"PowerOfRadiation", "==", "PowerOfConduction"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", "eqnOfHeatTransfer", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"power2", "=", 
     RowBox[{"PowerOfConduction", "/.", "%"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<power of heat loses= \>\"", ",", 
     FractionBox["power2", "1000"], ",", "\"\< kW\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<loses in the inductor= \>\"", ",", 
     FractionBox["inductorLoses", "1000"], ",", "\"\< kW\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<power of cooling system= \>\"", ",", 
     RowBox[{"powerToCool", "=", 
      RowBox[{
       FractionBox["power2", "1000"], "+", 
       FractionBox["inductorLoses", "1000"]}]}], ",", "\"\< kW\>\""}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7029676785367556`*^9, 3.702967688973174*^9}, {
  3.7029685198774333`*^9, 3.70296858057714*^9}, {3.7029693025017557`*^9, 
  3.7029693087885675`*^9}, {3.7029695128993254`*^9, 3.702969710036872*^9}, {
  3.702969818314664*^9, 3.702969826429266*^9}, {3.702969894166585*^9, 
  3.702969900016595*^9}, {3.70296999968517*^9, 3.7029701656538615`*^9}, {
  3.7029702216111603`*^9, 3.702970243107998*^9}, {3.70297028410487*^9, 
  3.7029703961910667`*^9}, {3.702970456173172*^9, 3.702970465267988*^9}, {
  3.7029705032228546`*^9, 3.702970658365127*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Tisol", "\[Rule]", "741.772662875891`"}], "}"}]], "Output",
 CellChangeTimes->{3.703571866502178*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"power of heat loses= \"\>", "\[InvisibleSpace]", 
   "21.28442969929117`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["power of heat loses= ", 21.28442969929117, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718665177784`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"loses in the inductor= \"\>", "\[InvisibleSpace]", 
   "597.4137761151956`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["loses in the inductor= ", 597.4137761151956, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718665177784`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"power of cooling system= \"\>", "\[InvisibleSpace]", 
   "618.6982058144868`", "\[InvisibleSpace]", "\<\" kW\"\>"}],
  SequenceForm["power of cooling system= ", 618.6982058144868, " kW"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035718665177784`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]T", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TofOutputFromCoil", "=", 
   RowBox[{"100", "-", "\[CapitalDelta]T"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TfromCoolingTower", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TofInputOfCoil", "=", "45"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", "4186"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"1000", "powerToCool"}], "\[Equal]", 
   RowBox[{"massFlow", "*", "c", "*", 
    RowBox[{"(", 
     RowBox[{"TofOutputFromCoil", "-", "TofInputOfCoil"}], ")"}]}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7029714229285173`*^9, 3.7029714915218377`*^9}, {
  3.7029715852780023`*^9, 3.702971605667238*^9}, {3.702971646227309*^9, 
  3.702971689688986*^9}, {3.702971722230643*^9, 3.702971723650245*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"massFlow", "\[Rule]", "2.9560353837290334`"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7035718665333786`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<kS of the heat exchanger= \>\"", ",", 
   FractionBox[
    RowBox[{"1000", "powerToCool"}], "\[CapitalDelta]T"], ",", " ", 
   "\"\< W/K\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7035727939726076`*^9, 3.703572871083543*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"kS of the heat exchanger= \"\>", "\[InvisibleSpace]", 
   "123739.64116289734`", "\[InvisibleSpace]", "\<\" W/K\"\>"}],
  SequenceForm["kS of the heat exchanger= ", 123739.64116289734`, " W/K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703572871801144*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["length"], "Input"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.7035733668212137`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mm", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"3", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eIdeal", "=", 
   RowBox[{"esol", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"chosenN2", "-", "1"}], ")"}], "*", "f"}], "+", 
        RowBox[{"chosenN2", "*", "esol"}]}], "\[Equal]", "length"}], "]"}], 
     "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<eIdeal= \>\"", ",", 
    FractionBox["eIdeal", "mm"], ",", "\"\< mm\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"38", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"chosenN2", "-", "1"}], ")"}], "*", "fchosen"}], "+", 
    RowBox[{"chosenN2", "*", "e"}]}], "\[Equal]", "length"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7035735353171096`*^9, 3.703573538343515*^9}, {
  3.703573696090992*^9, 3.7035737230322394`*^9}, {3.703573754279094*^9, 
  3.7035737975379705`*^9}, {3.7035740680736456`*^9, 3.7035741405669727`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"eIdeal= \"\>", "\[InvisibleSpace]", "37.87755102040816`", 
   "\[InvisibleSpace]", "\<\" mm\"\>"}],
  SequenceForm["eIdeal= ", 37.87755102040816, " mm"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.703574088260081*^9, 3.703574141331374*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"fchosen", "\[Rule]", "0.0028750000000000026`"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.703574118040533*^9, 3.703574141331374*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gIdeal", "=", 
   RowBox[{
    RowBox[{
     FractionBox["Pi", "2"], "*", 
     SqrtBox[
      FractionBox["2", 
       RowBox[{"\[Omega]", "*", "\[Gamma]", "*", "\[Mu]"}]]]}], "/.", 
    "params20"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<gIdeal= \>\"", ",", 
   FractionBox["gIdeal", "mm"], ",", "\"\< mm\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"15", "mm"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7035739085321655`*^9, 3.703574025594771*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gIdeal= \"\>", "\[InvisibleSpace]", "14.80872194397731`", 
   "\[InvisibleSpace]", "\<\" mm\"\>"}],
  SequenceForm["gIdeal= ", 14.80872194397731, " mm"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703574026234372*^9, 3.703574191829663*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "=", "e"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"5", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SH2Oflow", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"h", "-", 
      RowBox[{"15", "mm"}], "-", "t"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"e", "-", 
      RowBox[{"2", "t"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"radiusOfRotation", "=", 
   RowBox[{
    RowBox[{"0.5", "D2"}], "+", 
    RowBox[{"15", "mm"}], "+", 
    RowBox[{"0.5", "*", 
     RowBox[{"(", 
      RowBox[{"h", "-", 
       RowBox[{"15", "mm"}], "-", "t"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"internalSurface", "=", 
   RowBox[{"2", "*", "Pi", "*", "radiusOfRotation", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"h", "-", 
        RowBox[{"15", "mm"}], "-", "t"}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{"e", "-", 
        RowBox[{"2", "t"}]}], ")"}]}], ")"}], "*", "2", "*", "chosenN2"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7035746798841443`*^9, 3.703574707449393*^9}, {
  3.703574757868682*^9, 3.7035747945287457`*^9}, {3.7035748443864336`*^9, 
  3.703574848504841*^9}, {3.703575095822853*^9, 3.70357510555727*^9}, {
  3.7035751864902124`*^9, 3.7035752332278943`*^9}, {3.70357527617477*^9, 
  3.7035752961896048`*^9}, {3.703575387590165*^9, 3.7035753959517803`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"chosenMassFlor", "=", "3."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"densityH2O", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VolumeFlow", "=", 
   FractionBox["chosenMassFlor", "densityH2O"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"velocity", "=", 
   FractionBox["VolumeFlow", "SH2Oflow"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<velocity= \>\"", ",", "velocity", ",", 
   "\"\< m.\!\(\*SuperscriptBox[\(s\), \(-1\)]\)\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.7035755385984306`*^9, 3.7035756925551014`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"velocity= \"\>", "\[InvisibleSpace]", "5.952380952380953`", 
   "\[InvisibleSpace]", "\<\" m.\\!\\(\\*SuperscriptBox[\\(s\\), \\(-1\\)]\\)\
\"\>"}],
  SequenceForm[
  "velocity= ", 5.952380952380953, " m.\!\(\*SuperscriptBox[\(s\), \(-1\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703575693007502*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Dchar", "=", 
   FractionBox[
    RowBox[{"4", "*", "SH2O"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"15", "mm"}], "-", "t"}], ")"}], "+", 
       RowBox[{"(", 
        RowBox[{"e", "-", 
         RowBox[{"2", "t"}]}], ")"}]}], ")"}], "*", "2"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Dchar= \>\"", ",", 
   FractionBox["Dchar", "mm"], ",", "\"\< mm\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.7035757951252813`*^9, 3.703575842923765*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dchar= \"\>", "\[InvisibleSpace]", "21.913043478260864`", 
   "\[InvisibleSpace]", "\<\" mm\"\>"}],
  SequenceForm["Dchar= ", 21.913043478260864`, " mm"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035758435633664`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"viscosity", "=", 
   RowBox[{"0.5", "*", 
    RowBox[{"(", 
     RowBox[{"0.326", "+", "0.294"}], ")"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ReynoldsNumber", "=", 
   FractionBox[
    RowBox[{"velocity", "*", "Dchar"}], "viscosity"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Re= \>\"", ",", "ReynoldsNumber", ",", "\"\< -\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7035759957549696`*^9, 3.7035760721139565`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Re= \"\>", "\[InvisibleSpace]", "420757.36325385695`", 
   "\[InvisibleSpace]", "\<\" -\"\>"}],
  SequenceForm["Re= ", 420757.36325385695`, " -"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7035761561825047`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pr", "=", 
   RowBox[{"0.5", "*", 
    RowBox[{"(", 
     RowBox[{"1.96", "+", "1.75"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Pr= \>\"", ",", "Pr", ",", "\"\< -\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.703576242112212*^9, 3.7035762822035055`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pr= \"\>", "\[InvisibleSpace]", "1.855`", 
   "\[InvisibleSpace]", "\<\" -\"\>"}],
  SequenceForm["Pr= ", 1.855, " -"],
  Editable->False]], "Print",
 CellChangeTimes->{3.703576283036553*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nusselt", "=", 
   RowBox[{"0.023", "*", 
    SuperscriptBox["ReynoldsNumber", "0.8"], "*", 
    SuperscriptBox["Pr", "0.4"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"thermalConductivity", "=", "0.678"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alfa", "=", 
   FractionBox[
    RowBox[{"thermalConductivity", "*", "Nusselt"}], "Dchar"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\[Alpha]= \>\"", ",", "alfa", ",", 
    "\"\< W.\!\(\*SuperscriptBox[\(m\), \(-2\)]\).\!\(\*SuperscriptBox[\(K\), \
\(-1\)]\)\>\""}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.703576292271081*^9, 3.703576336775611*^9}, {
  3.703576397795745*^9, 3.7035764463155203`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[Alpha]= \"\>", "\[InvisibleSpace]", "28761.913440533677`", 
   "\[InvisibleSpace]", "\<\" W.\\!\\(\\*SuperscriptBox[\\(m\\), \
\\(-2\\)]\\).\\!\\(\\*SuperscriptBox[\\(K\\), \\(-1\\)]\\)\"\>"}],
  SequenceForm[
  "\[Alpha]= ", 28761.913440533677`, 
   " W.\!\(\*SuperscriptBox[\(m\), \(-2\)]\).\!\(\*SuperscriptBox[\(K\), \(-1\
\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.703576443887381*^9, 3.703576446901553*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"1000", "powerToCool"}], "internalSurface"], "\[Equal]", 
   RowBox[{"alfa", "*", 
    RowBox[{"(", 
     RowBox[{"Ta", "-", "95"}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.703576450095736*^9, 3.703576525137005*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"Ta", "\[Rule]", "98.91467377093491`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7035765259326067`*^9}]
}, Open  ]]
},
WindowSize->{1213, 761},
WindowMargins->{{6, Automatic}, {Automatic, 5}},
Magnification->2.299999952316284,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 210, 4, 68, "Input"],
Cell[CellGroupData[{
Cell[792, 28, 135, 2, 68, "Input"],
Cell[930, 32, 184, 4, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1151, 41, 376, 10, 195, "Input"],
Cell[1530, 53, 89, 1, 96, "Output"]
}, Open  ]],
Cell[1634, 57, 679, 17, 112, "Input"],
Cell[2316, 76, 548, 13, 112, "Input"],
Cell[CellGroupData[{
Cell[2889, 93, 488, 11, 97, "Input"],
Cell[3380, 106, 332, 10, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3749, 121, 413, 11, 97, "Input"],
Cell[4165, 134, 326, 9, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4528, 148, 1057, 28, 184, "Input"],
Cell[5588, 178, 1228, 40, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6853, 223, 457, 11, 141, "Input"],
Cell[7313, 236, 422, 10, 163, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7772, 251, 306, 8, 97, "Input"],
Cell[8081, 261, 550, 14, 186, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8668, 280, 216, 6, 97, "Input"],
Cell[8887, 288, 716, 20, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9640, 313, 239, 6, 97, "Input"],
Cell[9882, 321, 94, 1, 96, "Output"]
}, Open  ]],
Cell[9991, 325, 603, 15, 151, "Input"],
Cell[CellGroupData[{
Cell[10619, 344, 91, 2, 97, "Input"],
Cell[10713, 348, 387, 10, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11137, 363, 362, 9, 97, "Input"],
Cell[11502, 374, 5113, 91, 547, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16652, 470, 788, 21, 148, "Input"],
Cell[17443, 493, 837, 23, 157, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18317, 521, 598, 16, 270, "Input"],
Cell[18918, 539, 93, 1, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19048, 545, 855, 24, 257, "Input"],
Cell[19906, 571, 1491, 30, 584, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21434, 606, 1227, 37, 420, "Input"],
Cell[22664, 645, 1514, 29, 580, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24215, 679, 2169, 56, 923, "Input"],
Cell[CellGroupData[{
Cell[26409, 739, 290, 6, 49, "Print"],
Cell[26702, 747, 292, 6, 49, "Print"]
}, Open  ]]
}, Open  ]],
Cell[27021, 757, 2238, 63, 665, "Input"],
Cell[CellGroupData[{
Cell[29284, 824, 436, 8, 235, "Input"],
Cell[CellGroupData[{
Cell[29745, 836, 313, 7, 78, "Print"],
Cell[30061, 845, 310, 7, 78, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30420, 858, 802, 21, 290, "Input"],
Cell[31225, 881, 269, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31531, 892, 534, 15, 200, "Input"],
Cell[32068, 909, 331, 7, 51, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32436, 921, 479, 13, 194, "Input"],
Cell[32918, 936, 307, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33262, 947, 590, 16, 200, "Input"],
Cell[33855, 965, 377, 9, 51, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34269, 979, 381, 10, 194, "Input"],
Cell[34653, 991, 114, 2, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34804, 998, 174, 3, 97, "Input"],
Cell[34981, 1003, 386, 9, 151, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35404, 1017, 1864, 49, 489, "Input"],
Cell[37271, 1068, 141, 3, 96, "Output"],
Cell[37415, 1073, 92, 1, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37544, 1079, 313, 8, 141, "Input"],
Cell[37860, 1089, 416, 11, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38313, 1105, 505, 14, 252, "Input"],
Cell[38821, 1121, 306, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39164, 1132, 516, 14, 294, "Input"],
Cell[39683, 1148, 306, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40026, 1159, 286, 6, 207, "Input"],
Cell[40315, 1167, 284, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40636, 1178, 468, 12, 184, "Input"],
Cell[41107, 1192, 299, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41443, 1203, 747, 21, 319, "Input"],
Cell[42193, 1226, 264, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42494, 1237, 300, 7, 143, "Input"],
Cell[42797, 1246, 89, 1, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42923, 1252, 4184, 110, 1476, "Input"],
Cell[47110, 1364, 141, 3, 96, "Output"],
Cell[CellGroupData[{
Cell[47276, 1371, 302, 6, 49, "Print"],
Cell[47581, 1379, 306, 6, 49, "Print"],
Cell[47890, 1387, 310, 6, 49, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48249, 1399, 931, 21, 399, "Input"],
Cell[49183, 1422, 175, 5, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49395, 1432, 282, 6, 201, "Input"],
Cell[49680, 1440, 315, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50032, 1451, 32, 0, 97, "Input"],
Cell[50067, 1453, 72, 1, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50176, 1459, 1281, 36, 442, "Input"],
Cell[51460, 1497, 298, 6, 49, "Print"],
Cell[51761, 1505, 199, 5, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51997, 1515, 585, 17, 334, "Input"],
Cell[52585, 1534, 296, 6, 49, "Print"]
}, Open  ]],
Cell[52896, 1543, 1453, 41, 313, "Input"],
Cell[CellGroupData[{
Cell[54374, 1588, 640, 16, 369, "Input"],
Cell[55017, 1606, 365, 8, 51, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55419, 1619, 591, 18, 228, "Input"],
Cell[56013, 1639, 277, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56327, 1650, 568, 16, 237, "Input"],
Cell[56898, 1668, 269, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57204, 1679, 334, 8, 141, "Input"],
Cell[57541, 1689, 240, 6, 49, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57818, 1700, 766, 20, 277, "Input"],
Cell[58587, 1722, 482, 10, 51, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59106, 1737, 303, 8, 135, "Input"],
Cell[59412, 1747, 165, 4, 152, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
