(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     12500,        365]
NotebookOptionsPosition[     11909,        343]
NotebookOutlinePosition[     12288,        359]
CellTagsIndexPosition[     12245,        356]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quiet", "@", 
  RowBox[{"<<", "PhysicalConstants`"}]}]], "Input",
 CellChangeTimes->{{3.7005491305199304`*^9, 3.7005491419859505`*^9}, {
  3.7005491749332085`*^9, 3.700549189534834*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curl", "[", "vect_", "]"}], ":=", 
  RowBox[{"Curl", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"div", "[", "vect_", "]"}], ":=", 
  RowBox[{"Div", "[", 
   RowBox[{"vect", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grad", "[", "scal_", "]"}], ":=", 
  RowBox[{"Grad", "[", 
   RowBox[{"scal", ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", " ", 
    "\"\<Cylindrical\>\""}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.700550060742917*^9, 3.7005500616789184`*^9}, {
  3.7005501938755503`*^9, 3.700550278115699*^9}, {3.7005506417055373`*^9, 
  3.700550645012743*^9}, {3.702359568954666*^9, 3.7023595934155087`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Evect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"Efi", "[", "r", "]"}], ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hvect", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"Hz", "[", "r", "]"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.700550650020352*^9, 3.7005506818912077`*^9}, {
  3.7017518642136374`*^9, 3.701751869065246*^9}, {3.7017519056473103`*^9, 
  3.7017519075817137`*^9}, {3.701751957595402*^9, 3.7017519658322163`*^9}, {
  3.702357731269438*^9, 3.7023577543262787`*^9}}],

Cell[BoxData[
 RowBox[{"eqn1", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Hvect", "]"}], "\[Equal]", 
     RowBox[{"\[Gamma]", "*", "Evect"}]}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550692748827*^9, 3.7005507108136587`*^9}, {
   3.70055075148293*^9, 3.7005507581441417`*^9}, {3.700550802198619*^9, 
   3.700550809156231*^9}, 3.701751971292226*^9, {3.7017520121954975`*^9, 
   3.701752038294343*^9}, {3.7023577722663097`*^9, 3.702357798037555*^9}}],

Cell[BoxData[
 RowBox[{"eqn2", "=", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"curl", "[", "Evect", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", "I"}], "*", "\[Omega]", "*", "\[Mu]", "*", "Hvect"}]}], 
    "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.700550827314663*^9, 3.7005508948783817`*^9}, {
   3.701752068683197*^9, 3.701752094844443*^9}, 3.7023577937163477`*^9, {
   3.7023578342764187`*^9, 3.7023578364604225`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqn1", ",", "eqn2", ",", 
        RowBox[{
         RowBox[{"Hz", "[", "r2", "]"}], "\[Equal]", "H0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Efi", "[", "r", "]"}], ",", 
        RowBox[{"Hz", "[", "r", "]"}]}], "}"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solSimpl", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"sol", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", ">", "0"}], ",", 
       RowBox[{"r", ">", "0"}], ",", 
       RowBox[{"\[Mu]", ">", "0"}], ",", 
       RowBox[{"\[Gamma]", ">", "0"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7005509793369303`*^9, 3.700551034514227*^9}, {
   3.7005511058531523`*^9, 3.700551158612445*^9}, {3.700551745777836*^9, 
   3.700551750192643*^9}, {3.7017521067784634`*^9, 3.701752149054538*^9}, {
   3.701752650033818*^9, 3.7017526528106227`*^9}, {3.702357845633239*^9, 
   3.702357853495653*^9}, {3.7023580855304604`*^9, 3.702358102877691*^9}, 
   3.7023584403238835`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"boundaryEqn", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "Pi", "*", "r1", "*", 
        RowBox[{"Efi", "[", "r", "]"}]}], "/.", "solSimpl"}], "/.", 
      RowBox[{"r", "\[Rule]", "r1"}]}], ")"}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", "I"}], "*", "\[Omega]", "*", "Pi", "*", 
     SuperscriptBox["r2", "2"], "*", "\[Mu]", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Hz", "[", "r", "]"}], "/.", "solSimpl"}], "/.", 
       RowBox[{"r", "\[Rule]", "r1"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solC1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"boundaryEqn", ",", 
       RowBox[{"C", "[", "1", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"finalEfi", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Efi", "[", "r", "]"}], "/.", "solSimpl"}], "/.", "solC1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Mu]", "\[Rule]", 
      RowBox[{"4", "*", "Pi", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "7"}]]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{"57", "*", 
       SuperscriptBox["10", "6"]}]}], ",", 
     RowBox[{"f", "\[Rule]", "300"}], ",", 
     RowBox[{"r1", "\[Rule]", "0.05"}], ",", 
     RowBox[{"r2", "\[Rule]", "0.06"}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"2.", "*", "Pi", "*", "f"}]}], ",", 
     RowBox[{"H0", "\[Rule]", 
      SuperscriptBox["10", "7"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EfiNumeric", "=", 
   RowBox[{"finalEfi", "//.", "params"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Abs", "[", "EfiNumeric", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0.05", ",", "0.06"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"QV", "=", 
   RowBox[{
    RowBox[{"\[Gamma]", "*", 
     RowBox[{"Abs", "[", 
      SuperscriptBox["EfiNumeric", "2"], "]"}]}], "/.", "params"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"QV", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.05", ",", "0.06"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7023584492002993`*^9, 3.702358542597663*^9}, {
   3.7023585991477623`*^9, 3.7023586743554945`*^9}, {3.702359090860626*^9, 
   3.702359144805521*^9}, {3.702359240418089*^9, 3.7023593237066355`*^9}, 
   3.702359557441846*^9, 3.7023610449614477`*^9, 3.7023612347357807`*^9, 
   3.702361531138302*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"heatparams", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Rho]", "\[Rule]", "8900"}], ",", 
     RowBox[{"cp", "\[Rule]", "390"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "400"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"heatEqn", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "*", "cp", "*", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"r", ",", "t"}], "]"}], ",", "t"}], "]"}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"div", "[", 
       RowBox[{"\[Lambda]", "*", 
        RowBox[{"grad", "[", 
         RowBox[{"T", "[", 
          RowBox[{"r", ",", "t"}], "]"}], "]"}]}], "]"}], "+", "QV"}]}], "/.",
     "heatparams"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tamb", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"initcond", "=", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"r", ",", "0"}], "]"}], "\[Equal]", "Tamb"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"boundary1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "t"}], "]"}], "\[Equal]", "0"}], "/.", 
    RowBox[{"r", "\[Rule]", "r1"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{"5.67", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "8"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"boundary2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Lambda]"}], "*", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Alpha]", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"r", ",", "t"}], "]"}], "-", "Tamb"}], ")"}]}], "+", 
       RowBox[{"\[Epsilon]", "*", "\[Sigma]", "*", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"T", "[", 
              RowBox[{"r", ",", "t"}], "]"}], "+", "273"}], ")"}], "4"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"Tamb", "+", "273"}], ")"}], "4"]}], ")"}]}]}]}], "/.", 
     RowBox[{"r", "\[Rule]", "r2"}]}], "/.", "heatparams"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqnsTogether", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"heatEqn", ",", "initcond", ",", "boundary1", ",", "boundary2"}],
      "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r1", "\[Rule]", "0.05"}], ",", 
      RowBox[{"r2", "\[Rule]", "0.06"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"solT", "=", 
  RowBox[{
   RowBox[{"NDSolve", "[", 
    RowBox[{"eqnsTogether", ",", 
     RowBox[{"T", "[", 
      RowBox[{"r", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0.05", ",", "0.06"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7023596219167585`*^9, 3.7023597430665717`*^9}, {
   3.702359791171749*^9, 3.702359792267812*^9}, {3.702359862664571*^9, 
   3.702359865909376*^9}, {3.7023600809889545`*^9, 3.702360114763014*^9}, 
   3.702360161235495*^9, {3.7023602627448735`*^9, 3.702360277362099*^9}, {
   3.702360307485752*^9, 3.7023603082969537`*^9}, {3.702360394487105*^9, 
   3.70236057961263*^9}, {3.702360623401907*^9, 3.7023606857084165`*^9}, {
   3.702360911004012*^9, 3.7023609766177273`*^9}, 3.7023610729166965`*^9, {
   3.702361539858717*^9, 3.70236154159032*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"r", ",", "t"}], "]"}], "/.", "solT"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.05", ",", "0.06"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7023609840121403`*^9, 3.7023610170685987`*^9}, 
   3.702361449300558*^9, 3.7023615902000055`*^9}]
},
WindowSize->{1213, 761},
WindowMargins->{{12, Automatic}, {Automatic, 13}},
Magnification->2.299999952316284,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 210, 4, 68, "Input"],
Cell[770, 26, 982, 24, 184, "Input"],
Cell[1755, 52, 602, 15, 112, "Input"],
Cell[2360, 69, 536, 11, 68, "Input"],
Cell[2899, 82, 492, 12, 68, "Input"],
Cell[3394, 96, 1204, 30, 184, "Input"],
Cell[4601, 128, 2746, 78, 542, "Input"],
Cell[7350, 208, 4129, 120, 966, "Input"],
Cell[11482, 330, 423, 11, 97, "Input"]
}
]
*)

(* End of internal cache information *)
